@@ -90,6 +90,15 @@ def test_aqua_ubuntu_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_ubuntu2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3715.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 @pytest.fixture
 def test_aqua_ubuntu1_json():
     test_cve_data = os.path.join(
@@ -99,6 +108,15 @@ def test_aqua_ubuntu1_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_ubuntu3_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3219.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 @pytest.fixture
 def test_aqua_redhat_json():
     test_cve_data = os.path.join(
@@ -252,6 +270,8 @@ def test_aqua_convert(
     test_aqua_rlsa_json,
     test_aqua_ubuntu_json,
     test_aqua_ubuntu1_json,
+    test_aqua_ubuntu2_json,
+    test_aqua_ubuntu3_json,
     test_aqua_redhat_json,
     test_aqua_arch_json,
     test_aqua_opensuse_json,
@@ -269,6 +289,10 @@ def test_aqua_convert(
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_ubuntu1_json)
     assert not cve_data
+    cve_data = aqualatest.convert(test_aqua_ubuntu2_json)
+    assert cve_data
+    cve_data = aqualatest.convert(test_aqua_ubuntu3_json)
+    assert cve_data
     cve_data = aqualatest.convert(test_aqua_redhat_json)
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_arch_json)
