@@ -310,17 +310,43 @@ def test_os_build_compare():
     assert not res
     res = utils.version_compare("0.23.22-1.amzn2.0.1", 0, "*", None, "0.23.22")
     assert not res
-    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
-    assert not res
 
 
 def test_ubuntu_openssl():
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
+    assert not res
+    res = utils.version_compare(
+        "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.2"
+    )
+    assert not res
+    res = utils.version_compare(
+        "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.6"
+    )
+    assert not res
     res = utils.version_compare("1.10-0ubuntu4", 0, "*", None, "1.10-0ubuntu4.1")
     assert res
     res = utils.version_compare("2.2.19-3ubuntu2.1", 0, "*", None, "*")
     assert res
     res = utils.version_compare("2.2.19-3ubuntu2.1", 0, "*", None, None)
     assert res
+    res = utils.version_compare("2.34-0.1ubuntu9.1", 0, "*", None, "2.34-0.1ubuntu9.3")
+    assert res
+    res = utils.version_compare("3.0-1", 0, "*", None, "3.0-1ubuntu0.1")
+    assert res
+    res = utils.version_compare("2:8.39-12build1", 0, "*", None, "8.39-9ubuntu0.1")
+    assert not res
+    res = utils.version_compare(
+        "7.7.0+dfsg-1ubuntu1", 0, "*", None, "7.7.0+dfsg-1ubuntu1.1"
+    )
+    assert res
+    res = utils.version_compare("1.45.5-2ubuntu1", 0, "*", None, "1.45.5-1")
+    assert not res
+    res = utils.version_compare("3.0-1", 0, "*", None, "3.0-1ubuntu0.1")
+    assert res
+    res = utils.version_compare("10.34-7", 0, "*", None, "10.34-7ubuntu0.1")
+    assert res
+    res = utils.version_compare("2:6.2.0+dfsg-4", 0, "*", None, "2:6.2.0+dfsg-4ubuntu0.1")
+    assert res
 
 
 def test_debian_build_compare():
