@@ -331,7 +331,7 @@ class AquaSource(NvdSource):
         lastModifiedDate = cve_data.get("PublicDate")
         for pkg_name, distro_obj in packages.items():
             for distro_name, status_obj in distro_obj.items():
-                if distro_name in ("devel") or status_obj.get("Status") in (
+                if status_obj.get("Status") in (
                     "ignored",
                     "needs-triage",
                 ):
@@ -361,40 +361,44 @@ class AquaSource(NvdSource):
                     fix_version_start_including = fix_note
                     version_end_excluding = fix_note
                 # Handle CVEs that are deferred
-                if status_obj.get("Status") in ("deferred") and " " not in fix_note:
+                if (
+                    status_obj.get("Status") in ("deferred", "needed")
+                    and " " not in fix_note
+                ):
                     version_end_including = "99.99.9"
                 if pkg_name and (fix_version_start_including or version_end_including):
-                    tdata = config.CVE_TPL % dict(
-                        cve_id=cve_id,
-                        cwe_id=cwe_id,
-                        assigner=assigner,
-                        references=references,
-                        description="",
-                        vectorString=vectorString,
-                        vendor=vendor,
-                        product=pkg_name,
-                        version="*",
-                        version_start_including=version_start_including,
-                        version_end_including=version_end_including,
-                        version_start_excluding=version_start_excluding,
-                        version_end_excluding=version_end_excluding,
-                        fix_version_start_including=fix_version_start_including,
-                        fix_version_end_including=fix_version_end_including,
-                        fix_version_start_excluding=fix_version_start_excluding,
-                        fix_version_end_excluding=fix_version_end_excluding,
-                        severity=severity,
-                        attackComplexity=attackComplexity,
-                        score=score,
-                        exploitabilityScore=exploitabilityScore,
-                        publishedDate=publishedDate,
-                        lastModifiedDate=lastModifiedDate,
-                    )
-                    try:
-                        vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
-                        vuln.description = description
-                        ret_data.append(vuln)
-                    except Exception as e:
-                        pass
+                    for full_pkg_name in (f"{distro_name}/{pkg_name}", pkg_name):
+                        tdata = config.CVE_TPL % dict(
+                            cve_id=cve_id,
+                            cwe_id=cwe_id,
+                            assigner=assigner,
+                            references=references,
+                            description="",
+                            vectorString=vectorString,
+                            vendor=vendor,
+                            product=full_pkg_name,
+                            version="*",
+                            version_start_including=version_start_including,
+                            version_end_including=version_end_including,
+                            version_start_excluding=version_start_excluding,
+                            version_end_excluding=version_end_excluding,
+                            fix_version_start_including=fix_version_start_including,
+                            fix_version_end_including=fix_version_end_including,
+                            fix_version_start_excluding=fix_version_start_excluding,
+                            fix_version_end_excluding=fix_version_end_excluding,
+                            severity=severity,
+                            attackComplexity=attackComplexity,
+                            score=score,
+                            exploitabilityScore=exploitabilityScore,
+                            publishedDate=publishedDate,
+                            lastModifiedDate=lastModifiedDate,
+                        )
+                        try:
+                            vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
+                            vuln.description = description
+                            ret_data.append(vuln)
+                        except Exception as e:
+                            pass
         return ret_data
 
     def redhat_to_vuln(self, cve_data):
