@@ -31,12 +31,16 @@ except ImportError:
 
 json_lib = orjson if ORJSON_AVAILABLE else json
 
+vendor_overrides = {"apk": "alpine", "deb": "debian"}
+
 
 class OSVSource(NvdSource):
     """OSV CVE source"""
 
     def download_all(self, local_store=True):
         """Download all cve data"""
+        # For performance do not retain the whole data in-memory
+        # See: https://github.com/AppThreat/vulnerability-db/issues/27
         data_list = []
         for lang, url in config.osv_url_dict.items():
             data = self.fetch(url)
@@ -44,7 +48,6 @@ class OSVSource(NvdSource):
                 continue
             if local_store:
                 self.store(data)
-            data_list += data
         return data_list
 
     def download_recent(self, local_store=True):
@@ -193,6 +196,9 @@ class OSVSource(NvdSource):
             # Let's remove it to keep things sane
             if ":" in vendor:
                 vendor = vendor.split(":")[0]
+            # Substitute alpine for apk and debian for deb
+            if vendor_overrides.get(vendor):
+                vendor = vendor_overrides.get(vendor)
             for r in ranges:
                 events = r.get("events")
                 versions_list = r.get("versions", [])
