@@ -389,9 +389,10 @@ def is_epoch_mode(
 
 
 def trim_epoch_colon(s):
-    m = DEBIAN_VALID_VERSION.search(s)
-    if m and m.group("upstream_version"):
-        return m.group("upstream_version")
+    if "ubuntu" not in s:
+        m = DEBIAN_VALID_VERSION.search(s)
+        if m and m.group("upstream_version"):
+            return m.group("upstream_version")
     if ":" in s:
         return s.split(":")[1].split("-")[0]
     return s
@@ -460,6 +461,7 @@ def version_compare(
         min_affected_version_excluding,
         max_affected_version_excluding,
     )
+    ubuntu_mode_detected = False
     if epoch_mode_detected:
         (
             tcompare_ver,
@@ -478,6 +480,11 @@ def version_compare(
         if (
             tcompare_ver == tmax_version
             or tcompare_ver == tmax_affected_version_excluding
+            or (max_version and max_version.startswith(compare_ver))
+            or (
+                max_affected_version_excluding
+                and max_affected_version_excluding.startswith(compare_ver)
+            )
         ):
             if (
                 max_version
@@ -491,11 +498,51 @@ def version_compare(
                 and max_affected_version_excluding != compare_ver
             ):
                 return True
-        compare_ver = tcompare_ver
-        min_version = tmin_version
-        max_version = tmax_version
-        min_affected_version_excluding = tmin_affected_version_excluding
-        max_affected_version_excluding = tmax_affected_version_excluding
+        # Sorry about this but ubuntu versioning scheme is a PITA
+        if "ubuntu" in compare_ver or "build" in compare_ver:
+            compare_with_build_tag = False
+            # Trim any epoch
+            if ":" in compare_ver:
+                compare_ver = compare_ver.split(":")[-1]
+            if "ubuntu" in compare_ver:
+                tmpcvArr = compare_ver.split("ubuntu")
+            else:
+                tmpcvArr = compare_ver.split("build")
+                compare_with_build_tag = True
+            ubuntu_mode_detected = True
+            if max_version and ("ubuntu" in max_version or "-" in max_version):
+                if max_version.startswith(tmpcvArr[0]):
+                    tmpmv = max_version.split("ubuntu")[-1]
+                    compare_ver = tmpcvArr[-1]
+                else:
+                    tmpmv = max_version.split("ubuntu")[0]
+                    compare_ver = tmpcvArr[0]
+                max_version = tmpmv
+                if "-" in max_version:
+                    max_version = max_version.split("-")[0]
+            elif max_affected_version_excluding and (
+                "ubuntu" in max_affected_version_excluding
+                or "-" in max_affected_version_excluding
+            ):
+                if max_affected_version_excluding.startswith(tmpcvArr[0]):
+                    tmpmv = max_affected_version_excluding.split("ubuntu")[-1]
+                    compare_ver = tmpcvArr[-1]
+                else:
+                    tmpmv = max_affected_version_excluding.split("ubuntu")[0]
+                    compare_ver = tmpcvArr[0]
+                max_affected_version_excluding = tmpmv
+                if "-" in max_affected_version_excluding:
+                    max_affected_version_excluding = (
+                        max_affected_version_excluding.split("-")[0]
+                    )
+            if "-" in compare_ver:
+                compare_ver = compare_ver.split("-")[0]
+        if not ubuntu_mode_detected:
+            compare_ver = tcompare_ver
+            min_version = tmin_version
+            max_version = tmax_version
+            min_affected_version_excluding = tmin_affected_version_excluding
+            max_affected_version_excluding = tmax_affected_version_excluding
     # Semver compatible and including versions provided
     is_min_exclude = False
     is_max_exclude = False
